==> mcu_plus_sdk_am263x_08_06_00_34_docs_only.tar.xz: mcu_plus_sdk_am263x_08_06_00_34_docs_only/docs/api_guide_am263x/group__DRV__SOC__MODULE.js <==
var group__DRV__SOC__MODULE =
[
    [ "APIs for SOC Reset and Clock Functions", "group__DRV__SOC__RCM__MODULE.html", "group__DRV__SOC__RCM__MODULE" ],
    [ "APIs for SOC Xbars", "group__DRV__SOC__XBAR__MODULE.html", "group__DRV__SOC__XBAR__MODULE" ],
    [ "SOC_DOMAIN_ID_MAIN", "group__DRV__SOC__MODULE.html#ga5634a4a90145e695d07c6f7ef9818bf7", null ],
    [ "MSS_CTRL_PARTITION0", "group__DRV__SOC__MODULE.html#ga13e48a5725e4989bc07113b53fac89ba", null ],
    [ "TOP_CTRL_PARTITION0", "group__DRV__SOC__MODULE.html#ga62e031d233df2cd95c5a25261cbc850e", null ],
    [ "CONTROLSS_CTRL_PARTITION0", "group__DRV__SOC__MODULE.html#ga170be4fcbc5ce46989608c8421acf524", null ],
    [ "MSS_RCM_PARTITION0", "group__DRV__SOC__MODULE.html#ga26e5e1387a89275151cbba9489b24452", null ],
    [ "TOP_RCM_PARTITION0", "group__DRV__SOC__MODULE.html#ga762484341c146867c564e342653e286f", null ],
    [ "KICK_LOCK_VAL", "group__DRV__SOC__MODULE.html#ga9657e395c34c87f84b660a663eb2b3e1", null ],
    [ "KICK0_UNLOCK_VAL", "group__DRV__SOC__MODULE.html#gaf7d03694cad5d122cbb49eeca7d8ad7a", null ],
    [ "KICK1_UNLOCK_VAL", "group__DRV__SOC__MODULE.html#gacafea7a2a91a57de813abaed55475c61", null ],
    [ "SOC_moduleClockEnable", "group__DRV__SOC__MODULE.html#gada8123a7e779dfd49f7748349f7534be", null ],
    [ "SOC_moduleSetClockFrequency", "group__DRV__SOC__MODULE.html#ga608010ad392d6331d0a0519f8424aca7", null ],
    [ "SOC_getCoreName", "group__DRV__SOC__MODULE.html#ga56fa202291d97fe899178305711fedf6", null ],
    [ "SOC_getSelfCpuClk", "group__DRV__SOC__MODULE.html#ga33bb19e70642cf4aa8bfab89b52b49d6", null ],
    [ "SOC_controlModuleLockMMR", "group__DRV__SOC__MODULE.html#ga38a189038389b315104384f5d591cae8", null ],
    [ "SOC_controlModuleUnlockMMR", "group__DRV__SOC__MODULE.html#ga7b97815ae150f58089c2f44502710dec", null ],
    [ "SOC_setEpwmTbClk", "group__DRV__SOC__MODULE.html#gac389565caa4342dc40635cd2b214ee01", null ],
    [ "SOC_enableAdcReference", "group__DRV__SOC__MODULE.html#gae2c6127ab8fa6f7cceb1573f5b623f9d", null ],
    [ "SOC_setEpwmGroup", "group__DRV__SOC__MODULE.html#ga17e89ef0b269428665594da035e37dff", null ],
    [ "SOC_selectSdfm1Clk0Source", "group__DRV__SOC__MODULE.html#ga384a33b7bb9706de609f378fa259423a", null ],
    [ "SOC_gateEpwmClock", "group__DRV__SOC__MODULE.html#ga0f5ea8e232e1f1fdaeaa0b1614048e54", null ],
    [ "SOC_gateFsitxClock", "group__DRV__SOC__MODULE.html#gaf8807a81de930b70e9d891652d35df24", null ],
    [ "SOC_gateFsirxClock", "group__DRV__SOC__MODULE.html#ga0d803afc3d045f6f9063d5939d225087", null ],
    [ "SOC_gateCmpssaClock", "group__DRV__SOC__MODULE.html#ga40bb8a42552512d33f1908a67ba79840", null ],
    [ "SOC_gateCmpssbClock", "group__DRV__SOC__MODULE.html#gab4b74e1ffad7887ed70c723b8dd58fcd", null ],
    [ "SOC_gateEcapClock", "group__DRV__SOC__MODULE.html#ga1016ed99a9e3e42f093f94e8da4be5bd", null ],
    [ "SOC_gateEqepClock", "group__DRV__SOC__MODULE.html#ga8563a79ebe04e6b8fa678b18d65cf03b", null ],
    [ "SOC_gateSdfmClock", "group__DRV__SOC__MODULE.html#ga67d5748c0fa19bf46ba5b4dbcf470bba", null ],
    [ "SOC_gateDacClock", "group__DRV__SOC__MODULE.html#ga11292e5963664cba6c06812d2dcb918e", null ],
    [ "SOC_gateAdcClock", "group__DRV__SOC__MODULE.html#ga9591d4c088fd1d856ad9602c53e7ce18", null ],
    [ "SOC_gateOttoClock", "group__DRV__SOC__MODULE.html#gab68451b698fdcf8649eb4262437c402d", null ],
    [ "SOC_gateSdfmPllClock", "group__DRV__SOC__MODULE.html#ga4bf51ee5eeab943f16b4243041534e52", null ],
    [ "SOC_gateFsiPllClock", "group__DRV__SOC__MODULE.html#ga246b6267989d9184ef3abf683cb305fa", null ],
    [ "SOC_generateEpwmReset", "group__DRV__SOC__MODULE.html#ga93f7842c591a1dcb99a4a134878939ce", null ],
    [ "SOC_generateFsiTxReset", "group__DRV__SOC__MODULE.html#ga541f63a5919493e064b9b93be226de68", null ],
    [ "SOC_generateFsiRxReset", "group__DRV__SOC__MODULE.html#gaa497b01b87f1af15d94fd642b828b9a0", null ],
    [ "SOC_generateCmpssaReset", "group__DRV__SOC__MODULE.html#gaf09a10a7c18f32d7070f57cb37dd35aa", null ],
    [ "SOC_generateCmpssbReset", "group__DRV__SOC__MODULE.html#ga97c6d618660b47bf42f1245354c9e031", null ],
    [ "SOC_generateEcapReset", "group__DRV__SOC__MODULE.html#ga7da339db6729ef5b169741ef36e7441d", null ],
    [ "SOC_generateEqepReset", "group__DRV__SOC__MODULE.html#ga7398c49f0744a33b47a3b9a867ba21ca", null ],
    [ "SOC_generateSdfmReset", "group__DRV__SOC__MODULE.html#ga59bbe0807a1982f10161fe33335c15ad", null ],
    [ "SOC_generateDacReset", "group__DRV__SOC__MODULE.html#ga5fc7dab40edf82ea42221755ed7ced50", null ],
    [ "SOC_generateAdcReset", "group__DRV__SOC__MODULE.html#gacc3a68e44799c28c59bb37496d778fb5", null ],
    [ "Soc_enableEPWMHalt", "group__DRV__SOC__MODULE.html#ga59aa8fd73086da0b3212bed1b9bccda6", null ],
    [ "SOC_generateOttoReset", "group__DRV__SOC__MODULE.html#ga14ab1731f184ef1dd12b954225dcba5d", null ],
    [ "SOC_selectIcssGpiMux", "group__DRV__SOC__MODULE.html#ga8d4e609bf319d11a408ef078fc1df0f7", null ],
    [ "SOC_virtToPhy", "group__DRV__SOC__MODULE.html#ga9a3dd12ed6ec3bce4b786744c5cb134d", null ],
    [ "SOC_phyToVirt", "group__DRV__SOC__MODULE.html#ga91e92e9398edf29e171ad3974ca8ef1d", null ]
];

==> mcu_plus_sdk_am263x_11_01_00_19_docs_only.tar.xz: mcu_plus_sdk_am263x_11_01_00_19_docs_only/docs/api_guide_am263x/group__DRV__SOC__MODULE.js <==
var group__DRV__SOC__MODULE =
[
    [ "APIs for SOC Reset and Clock Functions", "group__DRV__SOC__RCM__MODULE.html", "group__DRV__SOC__RCM__MODULE" ],
    [ "APIs for SOC Xbars", "group__DRV__SOC__XBAR__MODULE.html", "group__DRV__SOC__XBAR__MODULE" ],
    [ "SOC_DOMAIN_ID_MAIN", "group__DRV__SOC__MODULE.html#ga5634a4a90145e695d07c6f7ef9818bf7", null ],
    [ "MSS_CTRL_PARTITION0", "group__DRV__SOC__MODULE.html#ga13e48a5725e4989bc07113b53fac89ba", null ],
    [ "TOP_CTRL_PARTITION0", "group__DRV__SOC__MODULE.html#ga62e031d233df2cd95c5a25261cbc850e", null ],
    [ "CONTROLSS_CTRL_PARTITION0", "group__DRV__SOC__MODULE.html#ga170be4fcbc5ce46989608c8421acf524", null ],
    [ "MSS_RCM_PARTITION0", "group__DRV__SOC__MODULE.html#ga26e5e1387a89275151cbba9489b24452", null ],
    [ "TOP_RCM_PARTITION0", "group__DRV__SOC__MODULE.html#ga762484341c146867c564e342653e286f", null ],
    [ "KICK_LOCK_VAL", "group__DRV__SOC__MODULE.html#ga9657e395c34c87f84b660a663eb2b3e1", null ],
    [ "KICK0_UNLOCK_VAL", "group__DRV__SOC__MODULE.html#gaf7d03694cad5d122cbb49eeca7d8ad7a", null ],
    [ "KICK1_UNLOCK_VAL", "group__DRV__SOC__MODULE.html#gacafea7a2a91a57de813abaed55475c61", null ],
    [ "IS_I2C_BASE_ADDR_VALID", "group__DRV__SOC__MODULE.html#ga9bc386272e1f7a83646e95cf379a97d3", null ],
    [ "IS_QSPI_BASE_ADDR_VALID", "group__DRV__SOC__MODULE.html#ga94b8fc387c5b2ca9ba935649e7689328", null ],
    [ "IS_QSPI_MEMORY_MAP_ADDR_VALID", "group__DRV__SOC__MODULE.html#gab9987f444e7cd8bf48f594815bd3a7da", null ],
    [ "MCSPI_lld_isBaseAddrValid", "group__DRV__SOC__MODULE.html#ga7475d97945d6a78df0e06815cc857a5c", null ],
    [ "MMCSD_lld_isBaseAddrValid", "group__DRV__SOC__MODULE.html#gaafb51d541c486179945c5997f6046224", null ],
    [ "SOC_moduleClockEnable", "group__DRV__SOC__MODULE.html#gada8123a7e779dfd49f7748349f7534be", null ],
    [ "SOC_moduleSetClockFrequency", "group__DRV__SOC__MODULE.html#ga608010ad392d6331d0a0519f8424aca7", null ],
    [ "SOC_getCoreName", "group__DRV__SOC__MODULE.html#ga56fa202291d97fe899178305711fedf6", null ],
    [ "SOC_getSelfCpuClk", "group__DRV__SOC__MODULE.html#ga33bb19e70642cf4aa8bfab89b52b49d6", null ],
    [ "SOC_controlModuleLockMMR", "group__DRV__SOC__MODULE.html#ga38a189038389b315104384f5d591cae8", null ],
    [ "SOC_controlModuleUnlockMMR", "group__DRV__SOC__MODULE.html#ga7b97815ae150f58089c2f44502710dec", null ],
    [ "SOC_setEpwmTbClk", "group__DRV__SOC__MODULE.html#gac389565caa4342dc40635cd2b214ee01", null ],
    [ "SOC_setMultipleEpwmTbClk", "group__DRV__SOC__MODULE.html#gac897f06d5b5735bbeaf4e21961c88df7", null ],
    [ "SOC_enableAdcReference", "group__DRV__SOC__MODULE.html#gae2c6127ab8fa6f7cceb1573f5b623f9d", null ],
    [ "SOC_enableAdcInternalReference", "group__DRV__SOC__MODULE.html#ga505aad31b6ceebd83d53e9968243c890", null ],
    [ "SOC_enableAdcReferenceMonitor", "group__DRV__SOC__MODULE.html#ga9704df12865db93adaf20edfa72216b8", null ],
    [ "SOC_getAdcReferenceStatus", "group__DRV__SOC__MODULE.html#ga1c364b054c3a44495db9eacd39736088", null ],
    [ "SOC_setEpwmGroup", "group__DRV__SOC__MODULE.html#ga17e89ef0b269428665594da035e37dff", null ],
    [ "SOC_selectSdfm1Clk0Source", "group__DRV__SOC__MODULE.html#ga384a33b7bb9706de609f378fa259423a", null ],
    [ "SOC_gateEpwmClock", "group__DRV__SOC__MODULE.html#ga0f5ea8e232e1f1fdaeaa0b1614048e54", null ],
    [ "SOC_ungateEpwmClock", "group__DRV__SOC__MODULE.html#ga2e5a8330d09a41e70141dc4784f5c191", null ],
    [ "SOC_gateFsitxClock", "group__DRV__SOC__MODULE.html#gaf8807a81de930b70e9d891652d35df24", null ],
    [ "SOC_gateFsirxClock", "group__DRV__SOC__MODULE.html#ga0d803afc3d045f6f9063d5939d225087", null ],
    [ "SOC_gateCmpssaClock", "group__DRV__SOC__MODULE.html#ga40bb8a42552512d33f1908a67ba79840", null ],
    [ "SOC_ungateCmpssaClock", "group__DRV__SOC__MODULE.html#gaefd36e2a9e73c7ffd1e21bbce62e3504", null ],
    [ "SOC_gateCmpssbClock", "group__DRV__SOC__MODULE.html#gab4b74e1ffad7887ed70c723b8dd58fcd", null ],
    [ "SOC_ungateCmpssbClock", "group__DRV__SOC__MODULE.html#gad132234e6692b8a963d3866e8c19b946", null ],
    [ "SOC_gateEcapClock", "group__DRV__SOC__MODULE.html#ga1016ed99a9e3e42f093f94e8da4be5bd", null ],
    [ "SOC_ungateEcapClock", "group__DRV__SOC__MODULE.html#ga8249acac8761896816e84f78130dfb2d", null ],
    [ "SOC_gateEqepClock", "group__DRV__SOC__MODULE.html#ga8563a79ebe04e6b8fa678b18d65cf03b", null ],
    [ "SOC_ungateEqepClock", "group__DRV__SOC__MODULE.html#ga09b719a308de7458597653b1a03f9b21", null ],
    [ "SOC_gateSdfmClock", "group__DRV__SOC__MODULE.html#ga67d5748c0fa19bf46ba5b4dbcf470bba", null ],
    [ "SOC_ungateSdfmClock", "group__DRV__SOC__MODULE.html#gaf2e86f538151fd869943b35dc962dc23", null ],
    [ "SOC_gateDacClock", "group__DRV__SOC__MODULE.html#ga11292e5963664cba6c06812d2dcb918e", null ],
    [ "SOC_ungateDacClock", "group__DRV__SOC__MODULE.html#gaf1e115b19fd1677fdafa35162107df88", null ],
    [ "SOC_gateAdcClock", "group__DRV__SOC__MODULE.html#ga9591d4c088fd1d856ad9602c53e7ce18", null ],
    [ "SOC_ungateAdcClock", "group__DRV__SOC__MODULE.html#ga7a76047e9f8b34de51fe73cac27c7bc4", null ],
    [ "SOC_gateOttoClock", "group__DRV__SOC__MODULE.html#gab68451b698fdcf8649eb4262437c402d", null ],
    [ "SOC_ungateOttoClock", "group__DRV__SOC__MODULE.html#gae670f370df3ecf5dbf6047a5b5da4ecb", null ],
    [ "SOC_gateSdfmPllClock", "group__DRV__SOC__MODULE.html#ga4bf51ee5eeab943f16b4243041534e52", null ],
    [ "SOC_ungateSdfmPllClock", "group__DRV__SOC__MODULE.html#ga6cbf7be7554c4a0726a493d42c6dd702", null ],
    [ "SOC_gateFsiPllClock", "group__DRV__SOC__MODULE.html#ga246b6267989d9184ef3abf683cb305fa", null ],
    [ "SOC_generateEpwmReset", "group__DRV__SOC__MODULE.html#ga93f7842c591a1dcb99a4a134878939ce", null ],
    [ "SOC_generateFsiTxReset", "group__DRV__SOC__MODULE.html#ga541f63a5919493e064b9b93be226de68", null ],
    [ "SOC_generateFsiRxReset", "group__DRV__SOC__MODULE.html#gaa497b01b87f1af15d94fd642b828b9a0", null ],
    [ "SOC_generateCmpssaReset", "group__DRV__SOC__MODULE.html#gaf09a10a7c18f32d7070f57cb37dd35aa", null ],
    [ "SOC_generateCmpssbReset", "group__DRV__SOC__MODULE.html#ga97c6d618660b47bf42f1245354c9e031", null ],
    [ "SOC_generateEcapReset", "group__DRV__SOC__MODULE.html#ga7da339db6729ef5b169741ef36e7441d", null ],
    [ "SOC_generateEqepReset", "group__DRV__SOC__MODULE.html#ga7398c49f0744a33b47a3b9a867ba21ca", null ],
    [ "SOC_generateSdfmReset", "group__DRV__SOC__MODULE.html#ga59bbe0807a1982f10161fe33335c15ad", null ],
    [ "SOC_generateDacReset", "group__DRV__SOC__MODULE.html#ga5fc7dab40edf82ea42221755ed7ced50", null ],
    [ "SOC_generateAdcReset", "group__DRV__SOC__MODULE.html#gacc3a68e44799c28c59bb37496d778fb5", null ],
    [ "Soc_enableEPWMHalt", "group__DRV__SOC__MODULE.html#ga59aa8fd73086da0b3212bed1b9bccda6", null ],
    [ "Soc_disableEPWMHalt", "group__DRV__SOC__MODULE.html#gae04470be7f88d3979046413da85cc46f", null ],
    [ "Soc_enableECAPHalt", "group__DRV__SOC__MODULE.html#ga52b1cc633a86a2bb7c96cd6f16b8e6d6", null ],
    [ "Soc_disableECAPHalt", "group__DRV__SOC__MODULE.html#gaf82bad0fcc61abe172f4ea112e32c632", null ],
    [ "SOC_generateOttoReset", "group__DRV__SOC__MODULE.html#ga14ab1731f184ef1dd12b954225dcba5d", null ],
    [ "SOC_selectIcssGpiMux", "group__DRV__SOC__MODULE.html#ga8d4e609bf319d11a408ef078fc1df0f7", null ],
    [ "SOC_setResetCPSWBit", "group__DRV__SOC__MODULE.html#ga6b18d9ae7fcfa9084f57621a087c650d", null ],
    [ "SOC_clearResetCPSWBit", "group__DRV__SOC__MODULE.html#ga5e5e352414910b246fb98d654bf86e76", null ],
    [ "SOC_virtToPhy", "group__DRV__SOC__MODULE.html#ga9a3dd12ed6ec3bce4b786744c5cb134d", null ],
    [ "SOC_phyToVirt", "group__DRV__SOC__MODULE.html#ga91e92e9398edf29e171ad3974ca8ef1d", null ],
    [ "SOC_configSlewRate", "group__DRV__SOC__MODULE.html#ga27ea1589a062cf65281e0854f5f706d1", null ],
    [ "UART_IsBaseAddrValid", "group__DRV__SOC__MODULE.html#ga3d169293015dbfab92d8147d889c76c3", null ],
    [ "SOC_getFlashDataBaseAddr", "group__DRV__SOC__MODULE.html#ga2830abb64f4f9a91ef77032e063b9418", null ]
];
